%define major		0
%define libname		%mklibname %name %major
%define develname	%mklibname %name -d

Summary: 	Online handwriting recognition system with machine learning
Name: 		zinnia
Version: 	0.07
Release: 	%mkrel 6
License: 	BSD
Group: 		System/Internationalization
URL: 		https://zinnia.sourceforge.net/
Source: 	https://github.com/silverhikari/zinnia/releases/download/%{version}/zinnia-%{version}.tar.gz
Patch0:		zinnia-0.05-bindings.patch
Patch1:		zinnia-python-module-version.patch
BuildRequires:	swig
BuildRequires:	perl-devel
BuildRequires:	pkgconfig(python3)

%description
Zinnia is a simple, customizable, and portable, online handwriting
recognition system based on Support Vector Machines. Zinnia receives
user pen strokes as a sequence of coordinate data and outputs n-best
characters sorted by their SVM confidence. To keep portability, Zinnia
doesn't have any rendering functionality. In addition to recognition,
Zinnia provides a training module that allows one to create any hand-
writing recognition systems at low-cost.

%package -n %libname
Summary:	Libraries for %name
Group:		System/Internationalization

%description -n %libname
This package contains shared libraries for %name.

%package -n %develname
Summary:	Development files for %name
Group:		System/Internationalization
Requires:	%libname = %version
Provides:	%name-devel = %version-%release

%description -n %develname
This package contains development files for %name.

%package -n perl-%name
Summary:	Perl bindings for %name
Group:		Development/Perl
Requires:	%{name} = %{version}

%description -n perl-%name
This package contains perl bindings for %name.

%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python

%description -n python3-%{name}
This package contains python3 bindings for %{name}.

%prep
%setup -q
%autopatch -p1

%build
# fix build on aarch64
autoreconf -vfi

%configure --disable-static
%make_build

pushd swig
make perl python ruby java
popd

pushd perl
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} OPTIMIZE="%{optflags}"
popd

pushd python
sed -i 's|zinnia.VERSION|%{version}|' setup.py
CFLAGS="%{optflags} -I../" CXXFLAGS="%{optflags} -I../" LDFLAGS="-L../.libs" %py3_build
popd

%install
%make_install

%make_install -C perl

pushd python
%py3_install
popd

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%{_bindir}/*

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

%files -n %develname
%doc doc/*
%{_includedir}/*.h
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n perl-%name
%dir %perl_vendorarch/auto/zinnia
%perl_vendorarch/auto/zinnia/zinnia.so
%perl_vendorarch/zinnia.pm

%files -n python3-%{name}
%{python3_sitearch}/_zinnia.*.so
%{python3_sitearch}/zinnia.py*
%{python3_sitearch}/zinnia_python-*info
%{python3_sitearch}/__pycache__/zinnia.*.py*


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 0.07-6.mga10
+ Revision: 2243003
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 0.07-5.mga10
+ Revision: 2160479
- rebuild for python3.13

* Mon Mar 03 2025 ns80 <ns80> 0.07-4.mga10
+ Revision: 2159517
- try to fix build

* Fri Aug 23 2024 tv <tv> 0.07-3.mga10
+ Revision: 2089702
- Rebuild for perl-5.40

* Thu Dec 28 2023 daviddavid <daviddavid> 0.07-2.mga10
+ Revision: 2023084
- rebuild for py3.12

* Tue Dec 05 2023 daviddavid <daviddavid> 0.07-1.mga10
+ Revision: 2013424
- new version: 0.07
- enable python3 bindings

* Tue Dec 05 2023 daviddavid <daviddavid> 0.06-31.mga10
+ Revision: 2013220
- rebuild for new perl 5.38.0

* Tue Jun 07 2022 umeabot <umeabot> 0.06-30.mga9
+ Revision: 1862790
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 0.06-29.mga9
+ Revision: 1796210
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 0.06-28.mga9
+ Revision: 1727391
- Rebuild for perl 5.34

* Fri Jun 26 2020 neoclust <neoclust> 0.06-27.mga8
+ Revision: 1599373
- Rebuild against new perl
+ umeabot <umeabot>
- Rebuild for perl 5.32

* Wed May 06 2020 wally <wally> 0.06-25.mga8
+ Revision: 1581344
- drop python2 bindings

* Sun Feb 16 2020 umeabot <umeabot> 0.06-24.mga8
+ Revision: 1530175
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 27 2019 tmb <tmb> 0.06-23.mga8
+ Revision: 1433958
- rebuild for perl 5.30

* Sun Sep 23 2018 umeabot <umeabot> 22.mga7-current
+ Revision: 1302054
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.06-21.mga7
+ Revision: 1249960
- Rebuild for perl 5.28

* Thu Aug 02 2018 wally <wally> 0.06-20.mga7
+ Revision: 1246959
- fix build on aarch64

* Tue Oct 10 2017 daviddavid <daviddavid> 0.06-19.mga7
+ Revision: 1170836
- patch1: fix build with gcc7
- rename python-zinnia to python2-zinnia
- use new python macros

* Thu Aug 31 2017 pterjan <pterjan> 0.06-18.mga7
+ Revision: 1149443
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 0.06-17.mga7
+ Revision: 1127638
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.06-16.mga6
+ Revision: 1036658
- Rebuild for perl 5.22.2

* Sat Feb 13 2016 umeabot <umeabot> 0.06-15.mga6
+ Revision: 959356
- Mageia 6 Mass Rebuild
+ shlomif <shlomif>
- Correct typos

* Sat Jun 27 2015 tv <tv> 0.06-14.mga6
+ Revision: 846147
- rebuild with soname-ified perl

* Tue Jun 23 2015 sander85 <sander85> 0.06-13.mga6
+ Revision: 841546
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.06-12.mga5
+ Revision: 746857
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.06-11.mga5
+ Revision: 730756
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.06-10.mga5
+ Revision: 690875
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 0.06-9.mga5
+ Revision: 631945
- Rebuild for perl 5.20
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.06-7.mga4
+ Revision: 544712
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.06-6.mga4
+ Revision: 500030
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed May 29 2013 fwang <fwang> 0.06-5.mga4
+ Revision: 430310
- rebuild for new perl

* Mon Jan 14 2013 umeabot <umeabot> 0.06-4.mga3
+ Revision: 387692
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 0.06-3.mga3
+ Revision: 251629
- perl 5.16 rebuild

* Sun Jun 12 2011 sander85 <sander85> 0.06-2.mga2
+ Revision: 105010
- Rebuild for perl 5.14

* Thu Apr 07 2011 tv <tv> 0.06-1.mga1
+ Revision: 81649
- imported package zinnia


* Tue Nov 02 2010 Funda Wang <fwang@mandriva.org> 0.06-1mdv2011.0
+ Revision: 592289
- add requires
- new version 0.06

* Thu Jul 22 2010 Jérôme Quelin <jquelin@mandriva.org> 0.05-2mdv2011.0
+ Revision: 556784
- perl 5.12 rebuild

* Thu Nov 19 2009 Jérôme Brenier <incubusss@mandriva.org> 0.05-1mdv2010.1
+ Revision: 467434
- new version 0.05
- rediff P0
- drop P1 (no more needed)
- requires : pkgconfig for the devel subpackage
- fix files section

* Mon Sep 21 2009 Thierry Vignaud <tv@mandriva.org> 0.02-3mdv2010.0
+ Revision: 446318
- rebuild

* Sun Feb 15 2009 Funda Wang <fwang@mandriva.org> 0.02-2mdv2009.1
+ Revision: 340609
- bump rel
- add bindings build

* Sun Feb 15 2009 Funda Wang <fwang@mandriva.org> 0.02-1mdv2009.1
+ Revision: 340500
- import zinnia


